@@ -96,8 +96,10 @@ static const PosKeycode keycodes_terminal[] = {
   { "*", KEY_8, POS_KEYCODE_MODIFIER_SHIFT },
   { "+", KEY_EQUAL, POS_KEYCODE_MODIFIER_SHIFT },
   { ",", KEY_COMMA, POS_KEYCODE_MODIFIER_NONE },
+  { "<", KEY_COMMA, POS_KEYCODE_MODIFIER_SHIFT },
   { "-", KEY_MINUS, POS_KEYCODE_MODIFIER_NONE },
   { ".", KEY_DOT, POS_KEYCODE_MODIFIER_NONE },
+  { ">", KEY_DOT, POS_KEYCODE_MODIFIER_SHIFT },
   { "/", KEY_SLASH, POS_KEYCODE_MODIFIER_NONE },
   { ":", KEY_SEMICOLON, POS_KEYCODE_MODIFIER_SHIFT },
   { ";", KEY_SEMICOLON, POS_KEYCODE_MODIFIER_NONE },
@@ -132,7 +134,7 @@ static const PosKeycode keycodes_terminal[] = {
   { "Z", KEY_Z, POS_KEYCODE_MODIFIER_SHIFT },
   { "[", KEY_LEFTBRACE, POS_KEYCODE_MODIFIER_NONE },
   { "\"", KEY_APOSTROPHE, POS_KEYCODE_MODIFIER_SHIFT },
-  { "\'", KEY_GRAVE, POS_KEYCODE_MODIFIER_NONE },
+  { "\'", KEY_APOSTROPHE, POS_KEYCODE_MODIFIER_NONE },
   { "\\", KEY_BACKSLASH, POS_KEYCODE_MODIFIER_NONE },
   { "]", KEY_RIGHTBRACE, POS_KEYCODE_MODIFIER_NONE },
   { "^", KEY_6, POS_KEYCODE_MODIFIER_SHIFT },
@@ -377,8 +379,9 @@ pos_vk_driver_build_keymap (PosVkDriver *self, PosKeysym extra_keysms[])
      * what we emit via `pos_vk_driver_key_down()`. As usual with xkb keymaps the keycodes
      * have an offset of `8`.
      */
-    g_string_append_printf (keycodes, "    <I%.3d>         = %d;\n", keycode->keycode + 8, keycode->keycode + 8);
-
+    g_string_append_printf (keycodes, "    <I%.3d>         = %d;\n",
+                            keycode->keycode + 8,
+                            keycode->keycode + 8);
     /*
      * For characters map each symbol as 'U<UCS4>' to the keycodes added above
      * See /usr/include/X11/keysymdef.h
@@ -454,21 +457,16 @@ pos_vk_driver_build_keymap (PosVkDriver *self, PosKeysym extra_keysms[])
 
 
 static void
-pos_vk_driver_update_keycodes (PosVkDriver *self, const char *layout_id)
+pos_vk_driver_update_terminal_keycodes (PosVkDriver *self)
 {
-  const PosKeycode *keycodes = keycodes_terminal;
-
   g_clear_pointer (&self->keycodes, g_hash_table_destroy);
 
   self->keycodes = g_hash_table_new (g_str_hash, g_str_equal);
   for (int i = 0; i < G_N_ELEMENTS (keycodes_common); i++)
     g_hash_table_insert (self->keycodes, keycodes_common[i].key,  (gpointer)&keycodes_common[i]);
 
-  if (g_strcmp0 (layout_id, "terminal"))
-    g_warning ("Unknown layout id '%s', will use terminal layout", layout_id);
-
-  for (int i = 0; keycodes[i].key != NULL; i++)
-    g_hash_table_insert (self->keycodes, keycodes[i].key,  (gpointer)&keycodes[i]);
+  for (int i = 0; keycodes_terminal[i].key != NULL; i++)
+    g_hash_table_insert (self->keycodes, keycodes_terminal[i].key,  (gpointer)&keycodes_terminal[i]);
 }
 
 
@@ -542,7 +540,7 @@ pos_vk_driver_new (PosVirtualKeyboard *virtual_keyboard)
 }
 
 /**
- * pos_vk_driver_new_down:
+ * pos_vk_driver_key_down:
  * @self: The virtual keyboard driver
  * @key: The key to press
  * @modifiers: Additional modifiers
@@ -661,8 +659,7 @@ pos_vk_driver_key_press_gdk (PosVkDriver *self, guint gdk_keycode, GdkModifierTy
  * pos_vk_driver_set_terminal_keymap:
  * @self: The vk driver
  *
- * Sets the given keymap honoring xkb-options set in GNOME. When possible send
- * keycodes matching that layout id.
+ * Sets the terminal keymap.
  */
 void
 pos_vk_driver_set_terminal_keymap (PosVkDriver *self)
@@ -686,7 +683,7 @@ pos_vk_driver_set_terminal_keymap (PosVkDriver *self)
 
   pos_virtual_keyboard_set_keymap (self->virtual_keyboard, keymap);
 
-  pos_vk_driver_update_keycodes (self, layout_id);
+  pos_vk_driver_update_terminal_keycodes (self);
 }
 
 /**
